@@ -16,18 +16,13 @@
 
 
 from . import Image, ImageFile
-from ._binary import i8
-
-# __version__ is deprecated and will be removed in a future version. Use
-# PIL.__version__ instead.
-__version__ = "0.1"
-
 
 ##
 # Image plugin for PhotoCD images.  This plugin only reads the 768x512
 # image from the file; higher resolutions are encoded in a proprietary
 # encoding.
 
+
 class PcdImageFile(ImageFile.ImageFile):
 
     format = "PCD"
@@ -42,7 +37,7 @@ class PcdImageFile(ImageFile.ImageFile):
         if s[:4] != b"PCD_":
             raise SyntaxError("not a PCD file")
 
-        orientation = i8(s[1538]) & 3
+        orientation = s[1538] & 3
         self.tile_post_rotate = None
         if orientation == 1:
             self.tile_post_rotate = 90
@@ -51,7 +46,7 @@ class PcdImageFile(ImageFile.ImageFile):
 
         self.mode = "RGB"
         self._size = 768, 512  # FIXME: not correct for rotated images!
-        self.tile = [("pcd", (0, 0)+self.size, 96*2048, None)]
+        self.tile = [("pcd", (0, 0) + self.size, 96 * 2048, None)]
 
     def load_end(self):
         if self.tile_post_rotate:
